==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/el_gr/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Στατιστικές πληροφορίες δεν είναι επί του παρόντος διαθέσιμες.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Αξία';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Πεδίο';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Πληροφορίες';
$lang['DirectAdmin.tab_client_stats'] = 'Στατιστικά στοιχεία';
$lang['DirectAdmin.edit_row.add_btn'] = 'Επεξεργασία διακομιστή';
$lang['DirectAdmin.edit_row.notes_title'] = 'Σημειώσεις';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Αφαιρέστε το';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Όνομα κεντρικού υπολογιστή';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Διακομιστής ονομάτων';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Προσθήκη πρόσθετου διακομιστή ονομάτων';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Εξυπηρετητές ονομάτων';
$lang['DirectAdmin.edit_row.basic_title'] = 'Βασικές ρυθμίσεις';
$lang['DirectAdmin.edit_row.box_title'] = 'Επεξεργασία διακομιστή DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Προσθήκη διακομιστή';
$lang['DirectAdmin.add_row.notes_title'] = 'Σημειώσεις';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Αφαιρέστε το';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Όνομα κεντρικού υπολογιστή';
$lang['DirectAdmin.add_row.name_server_col'] = 'Διακομιστής ονομάτων';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Προσθήκη πρόσθετου διακομιστή ονομάτων';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Εξυπηρετητές ονομάτων';
$lang['DirectAdmin.add_row.basic_title'] = 'Βασικές ρυθμίσεις';
$lang['DirectAdmin.add_row.box_title'] = 'Προσθήκη διακομιστή DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Διακομιστής ονομάτων %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Όριο λογαριασμού';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Χρησιμοποιήστε SSL κατά τη σύνδεση στο API (συνιστάται)';
$lang['DirectAdmin.row_meta.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.row_meta.user_name'] = 'Όνομα χρήστη';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Λιμάνι';
$lang['DirectAdmin.row_meta.host_name'] = 'Όνομα οικοδεσπότη';
$lang['DirectAdmin.row_meta.server_name'] = 'Ετικέτα διακομιστή';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την ομάδα διακομιστών;';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτόν τον διακομιστή;';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Διαγραφή';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Διαγραφή';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Επεξεργασία';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Επεξεργασία';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Επιλογές';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Αριθμός διακομιστών';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Όνομα ομάδας';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Επιλογές';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Λογαριασμοί';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Όνομα οικοδεσπότη';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Ετικέτα διακομιστή';
$lang['DirectAdmin.manage.module_groups_title'] = 'Ομάδες διακομιστών';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servers';
$lang['DirectAdmin.add_module_group'] = 'Προσθήκη ομάδας διακομιστών';
$lang['DirectAdmin.add_module_row'] = 'Προσθήκη διακομιστή';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Ανάθεση';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Κοινόχρηστο';
$lang['DirectAdmin.package_fields.ip'] = 'Διεύθυνση IP';
$lang['DirectAdmin.package_fields.package'] = 'Πακέτο DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Μεταπωλητής';
$lang['DirectAdmin.package_fields.type_user'] = 'Χρήστης';
$lang['DirectAdmin.package_fields.type'] = 'Τύπος λογαριασμού';
$lang['DirectAdmin.service_info.option_login'] = 'Συνδεθείτε';
$lang['DirectAdmin.service_info.options'] = 'Επιλογές';
$lang['DirectAdmin.service_info.server'] = 'Διακομιστής';
$lang['DirectAdmin.service_info.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.service_info.username'] = 'Όνομα χρήστη';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Δημιουργία κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Ενημέρωση κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Επιβεβαίωση κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Αλλαγή κωδικού πρόσβασης';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Δημιουργία κωδικού πρόσβασης';
$lang['DirectAdmin.service_field.email'] = 'Ηλεκτρονικό ταχυδρομείο';
$lang['DirectAdmin.service_field.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.service_field.username'] = 'Όνομα χρήστη';
$lang['DirectAdmin.service_field.domain'] = 'Τομέας';
$lang['DirectAdmin.server_groups.no_results'] = 'Δεν υπάρχουν ομάδες διακομιστών.';
$lang['DirectAdmin.servers.no_results'] = 'Δεν υπάρχουν διακομιστές.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Ομοιόμορφη κατανομή μεταξύ των διακομιστών';
$lang['DirectAdmin.order_options.first'] = 'Πρώτος μη πλήρης διακομιστής';
$lang['DirectAdmin.tab_client_actions'] = 'Δράσεις';
$lang['DirectAdmin.tab_stats'] = 'Στατιστικά στοιχεία';
$lang['DirectAdmin.module_group'] = 'Ομάδα διακομιστών';
$lang['DirectAdmin.module_row_plural'] = 'Servers';
$lang['DirectAdmin.module_row'] = 'Διακομιστής';
$lang['DirectAdmin.description'] = 'Το DirectAdmin είναι ένας γραφικός διαδικτυακός πίνακας ελέγχου φιλοξενίας ιστοσελίδων που έχει σχεδιαστεί για να διευκολύνει τη διαχείριση των ιστοσελίδων.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Η ενότητα δεν υποστηρίζει την αλλαγή μεταξύ πακέτων χρηστών και μεταπωλητών.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Παρακαλούμε εισάγετε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Ο κωδικός πρόσβασης και ο κωδικός επιβεβαίωσης δεν ταιριάζουν.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Βεβαιωθείτε ότι ο κωδικός πρόσβασης περιέχει τα εξής: Τουλάχιστον 12 χαρακτήρες, τουλάχιστον 1 κεφαλαίο χαρακτήρα A-Z, τουλάχιστον 1 πεζό χαρακτήρα a-z, τουλάχιστον 1 αριθμό 0-9 και τουλάχιστον 1 ειδικό χαρακτήρα από το σύνολο: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Το όνομα χρήστη πρέπει να έχει μήκος μεταξύ 4 και 8 χαρακτήρων.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Το όνομα χρήστη μπορεί να περιέχει μόνο αλφαριθμητικούς χαρακτήρες.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Παρακαλώ εισάγετε ένα έγκυρο όνομα τομέα της μορφής: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Απαιτείται μια διεύθυνση IP.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Απαιτείται ένα πακέτο DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Ο Τύπος λογαριασμού πρέπει να είναι είτε χρήστης είτε μεταπωλητής.';
$lang['DirectAdmin.!error.api.internal'] = 'Προέκυψε ένα εσωτερικό σφάλμα ή ο διακομιστής δεν απάντησε στην αίτηση.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Πρέπει να ορίσετε τουλάχιστον 2 διακομιστές ονομάτων.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Ένας ή περισσότεροι από τους καταχωρημένους διακομιστές ονομάτων είναι άκυροι.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Το Όριο λογαριασμού πρέπει να παραμείνει κενό (για απεριόριστους λογαριασμούς) ή να οριστεί σε κάποια ακέραια τιμή.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Η επιλογή Use SSL πρέπει να είναι true ή false.';
$lang['DirectAdmin.!error.password.format'] = 'Πρέπει να εισαγάγετε έναν κωδικό πρόσβασης.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Πρέπει να εισαγάγετε ένα όνομα χρήστη.';
$lang['DirectAdmin.!error.port.format'] = 'Η θύρα πρέπει να είναι αριθμός.';
$lang['DirectAdmin.!error.host_name.format'] = 'Το όνομα κεντρικού υπολογιστή φαίνεται να είναι άκυρο.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Πρέπει να εισαγάγετε μια ετικέτα διακομιστή.';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/el_gr/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Στατιστικές πληροφορίες δεν είναι επί του παρόντος διαθέσιμες.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Αξία';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Πεδίο';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Πληροφορίες';
$lang['DirectAdmin.tab_client_stats'] = 'Στατιστικά στοιχεία';
$lang['DirectAdmin.edit_row.add_btn'] = 'Επεξεργασία διακομιστή';
$lang['DirectAdmin.edit_row.notes_title'] = 'Σημειώσεις';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Αφαιρέστε το';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Όνομα κεντρικού υπολογιστή';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Διακομιστής ονομάτων';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Προσθήκη πρόσθετου διακομιστή ονομάτων';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Εξυπηρετητές ονομάτων';
$lang['DirectAdmin.edit_row.basic_title'] = 'Βασικές ρυθμίσεις';
$lang['DirectAdmin.edit_row.box_title'] = 'Επεξεργασία διακομιστή DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Προσθήκη διακομιστή';
$lang['DirectAdmin.add_row.notes_title'] = 'Σημειώσεις';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Αφαιρέστε το';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Όνομα κεντρικού υπολογιστή';
$lang['DirectAdmin.add_row.name_server_col'] = 'Διακομιστής ονομάτων';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Προσθήκη πρόσθετου διακομιστή ονομάτων';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Εξυπηρετητές ονομάτων';
$lang['DirectAdmin.add_row.basic_title'] = 'Βασικές ρυθμίσεις';
$lang['DirectAdmin.add_row.box_title'] = 'Προσθήκη διακομιστή DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Διακομιστής ονομάτων %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Όριο λογαριασμού';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Χρησιμοποιήστε SSL κατά τη σύνδεση στο API (συνιστάται)';
$lang['DirectAdmin.row_meta.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.row_meta.user_name'] = 'Όνομα χρήστη';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Λιμάνι';
$lang['DirectAdmin.row_meta.host_name'] = 'Όνομα οικοδεσπότη';
$lang['DirectAdmin.row_meta.server_name'] = 'Ετικέτα διακομιστή';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την ομάδα διακομιστών;';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτόν τον διακομιστή;';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Διαγραφή';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Διαγραφή';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Επεξεργασία';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Επεξεργασία';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Επιλογές';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Αριθμός διακομιστών';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Όνομα ομάδας';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Επιλογές';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Λογαριασμοί';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Όνομα οικοδεσπότη';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Ετικέτα διακομιστή';
$lang['DirectAdmin.manage.module_groups_title'] = 'Ομάδες διακομιστών';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servers';
$lang['DirectAdmin.add_module_group'] = 'Προσθήκη ομάδας διακομιστών';
$lang['DirectAdmin.add_module_row'] = 'Προσθήκη διακομιστή';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Ανάθεση';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Κοινόχρηστο';
$lang['DirectAdmin.package_fields.ip'] = 'Διεύθυνση IP';
$lang['DirectAdmin.package_fields.package'] = 'Πακέτο DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Μεταπωλητής';
$lang['DirectAdmin.package_fields.type_user'] = 'Χρήστης';
$lang['DirectAdmin.package_fields.type'] = 'Τύπος λογαριασμού';
$lang['DirectAdmin.service_info.option_login'] = 'Συνδεθείτε';
$lang['DirectAdmin.service_info.options'] = 'Επιλογές';
$lang['DirectAdmin.service_info.server'] = 'Διακομιστής';
$lang['DirectAdmin.service_info.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.service_info.username'] = 'Όνομα χρήστη';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Δημιουργία κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Ενημέρωση κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Επιβεβαίωση κωδικού πρόσβασης';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Αλλαγή κωδικού πρόσβασης';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Δημιουργία κωδικού πρόσβασης';
$lang['DirectAdmin.service_field.email'] = 'Ηλεκτρονικό ταχυδρομείο';
$lang['DirectAdmin.service_field.password'] = 'Κωδικός πρόσβασης';
$lang['DirectAdmin.service_field.username'] = 'Όνομα χρήστη';
$lang['DirectAdmin.service_field.domain'] = 'Τομέας';
$lang['DirectAdmin.server_groups.no_results'] = 'Δεν υπάρχουν ομάδες διακομιστών.';
$lang['DirectAdmin.servers.no_results'] = 'Δεν υπάρχουν διακομιστές.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Ομοιόμορφη κατανομή μεταξύ των διακομιστών';
$lang['DirectAdmin.order_options.first'] = 'Πρώτος μη πλήρης διακομιστής';
$lang['DirectAdmin.tab_client_actions'] = 'Δράσεις';
$lang['DirectAdmin.tab_stats'] = 'Στατιστικά στοιχεία';
$lang['DirectAdmin.module_group'] = 'Ομάδα διακομιστών';
$lang['DirectAdmin.module_row_plural'] = 'Servers';
$lang['DirectAdmin.module_row'] = 'Διακομιστής';
$lang['DirectAdmin.description'] = 'Το DirectAdmin είναι ένας γραφικός διαδικτυακός πίνακας ελέγχου φιλοξενίας ιστοσελίδων που έχει σχεδιαστεί για να διευκολύνει τη διαχείριση των ιστοσελίδων.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Η ενότητα δεν υποστηρίζει την αλλαγή μεταξύ πακέτων χρηστών και μεταπωλητών.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Παρακαλούμε εισάγετε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Ο κωδικός πρόσβασης και ο κωδικός επιβεβαίωσης δεν ταιριάζουν.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Βεβαιωθείτε ότι ο κωδικός πρόσβασης περιέχει τα εξής: Τουλάχιστον 12 χαρακτήρες, τουλάχιστον 1 κεφαλαίο χαρακτήρα A-Z, τουλάχιστον 1 πεζό χαρακτήρα a-z, τουλάχιστον 1 αριθμό 0-9 και τουλάχιστον 1 ειδικό χαρακτήρα από το σύνολο: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Το όνομα χρήστη πρέπει να έχει μήκος μεταξύ 4 και 8 χαρακτήρων.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Το όνομα χρήστη μπορεί να περιέχει μόνο αλφαριθμητικούς χαρακτήρες.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Παρακαλώ εισάγετε ένα έγκυρο όνομα τομέα της μορφής: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Απαιτείται μια διεύθυνση IP.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Απαιτείται ένα πακέτο DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Ο Τύπος λογαριασμού πρέπει να είναι είτε χρήστης είτε μεταπωλητής.';
$lang['DirectAdmin.!error.api.internal'] = 'Προέκυψε ένα εσωτερικό σφάλμα ή ο διακομιστής δεν απάντησε στην αίτηση.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Πρέπει να ορίσετε τουλάχιστον 2 διακομιστές ονομάτων.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Ένας ή περισσότεροι από τους καταχωρημένους διακομιστές ονομάτων είναι άκυροι.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Το Όριο λογαριασμού πρέπει να παραμείνει κενό (για απεριόριστους λογαριασμούς) ή να οριστεί σε κάποια ακέραια τιμή.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Η επιλογή Use SSL πρέπει να είναι true ή false.';
$lang['DirectAdmin.!error.password.format'] = 'Πρέπει να εισαγάγετε έναν κωδικό πρόσβασης.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Πρέπει να εισαγάγετε ένα όνομα χρήστη.';
$lang['DirectAdmin.!error.port.format'] = 'Η θύρα πρέπει να είναι αριθμός.';
$lang['DirectAdmin.!error.host_name.format'] = 'Το όνομα κεντρικού υπολογιστή φαίνεται να είναι άκυρο.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Πρέπει να εισαγάγετε μια ετικέτα διακομιστή.';
$lang['DirectAdmin.row_meta.ip_address'] = 'Διεύθυνση IP';
$lang['DirectAdmin.!error.ip_address.format'] = 'Η διεύθυνση IP φαίνεται να είναι άκυρη.';
